@@ -1,8 +1,4 @@
-import re
-from venmo_api import User
-from venmo_api import Transaction
-from venmo_api import InvalidArgumentError
-from venmo_api import deserialize, wrap_callback, get_user_id
+from venmo_api import User, Page, Transaction, deserialize, wrap_callback, get_user_id
 from typing import List, Union
 
 
@@ -38,13 +34,14 @@ class UserApi(object):
         return self.__profile
 
     def search_for_users(self, query: str, callback=None,
-                         page: int = 1, count: int = 50) -> Union[List[User], None]:
+                         offset: int = 0, limit: int = 50, username=False) -> Union[List[User], None]:
         """
         search for [query] in users
-        :param query: <str>
-        :param callback: <function>
-        :param count: <int>
-        :param page: <int>
+        :param query:
+        :param callback:
+        :param offset:
+        :param limit:
+        :param username: default: False; Pass True if search is by username
         :return users_list: <list> A list of <User> objects or empty
         """
 
@@ -52,12 +49,10 @@ class UserApi(object):
         wrapped_callback = wrap_callback(callback=callback,
                                          data_type=User)
 
-        offset_limit_params = self.__prepare_offset_limit_params(page_number=page,
-                                                                 max_number_per_page=50,
-                                                                 max_offset=9900,
-                                                                 count=count)
-        params = {'query': query}
-        params.update(offset_limit_params)
+        params = {'query': query, 'limit': limit, 'offset': offset}
+        # update params for querying by username
+        if username or '@' in query:
+            params.update({'query': query.replace('@', ''), 'type': 'username'})
 
         response = self.__api_client.call_api(resource_path=resource_path, params=params,
                                               method='GET', callback=wrapped_callback)
@@ -65,7 +60,12 @@ class UserApi(object):
         if callback:
             return
 
-        return deserialize(response=response, data_type=User)
+        return deserialize(response=response,
+                           data_type=User).set_method(method=self.search_for_users,
+                                                      kwargs={"query": query, "limit": limit},
+                                                      current_offset=offset
+                                                      )
+
 
     def get_user(self, user_id: str, callback=None) -> Union[User, None]:
         """
@@ -89,20 +89,31 @@ class UserApi(object):
 
         return deserialize(response=response, data_type=User)
 
+    def get_user_by_username(self, username: str) -> Union[User, None]:
+        """
+        Get the user profile with [username]
+        :param username:
+        :return user: <User> <NoneType>
+        """
+        users = self.search_for_users(query=username, username=True)
+        for user in users:
+            if user.username == username:
+                return user
+
+        # username not found
+        return None
+
     def get_user_friends_list(self, user_id: str = None,
                               user: User = None,
                               callback=None,
-                              page: int = 1,
-                              count: int = 1337) -> Union[User, None]:
+                              offset: int = 0,
+                              limit: int = 3337) -> Union[Page, None]:
         """
         Get ([user_id]'s or [user]'s) friends list as a list of <User>s
         :return users_list: <list> A list of <User> objects or empty
         """
         user_id = get_user_id(user, user_id)
-        params = self.__prepare_offset_limit_params(page_number=page,
-                                                    max_number_per_page=1337,
-                                                    max_offset=9999999999999999999,
-                                                    count=count)
+        params = {"limit": limit, "offset": offset}
 
         # Prepare the request
         resource_path = f'/users/{user_id}/friends'
@@ -116,24 +127,29 @@ class UserApi(object):
         if callback:
             return
 
-        return deserialize(response=response, data_type=User)
+        return deserialize(
+            response=response,
+            data_type=User).set_method(method=self.get_user_friends_list,
+                                       kwargs={"user_id": user_id, "limit": limit},
+                                       current_offset=offset
+                                       )
 
     def get_user_transactions(self, user_id: str = None, user: User = None,
                               callback=None,
-                              count: int = 50,
-                              before_id=None) -> Union[Transaction, None]:
+                              limit: int = 50,
+                              before_id=None) -> Union[Page, None]:
         """
         Get ([user_id]'s or [user]'s) transactions visible to yourself as a list of <Transaction>s
         :param user_id:
         :param user:
         :param callback:
-        :param count:
+        :param limit:
         :param before_id:
         :return:
         """
         user_id = get_user_id(user, user_id)
 
-        params = {'limit': count}
+        params = {'limit': limit}
         if before_id:
             params['before_id'] = before_id
 
@@ -150,15 +166,17 @@ class UserApi(object):
         if callback:
             return
 
-        return deserialize(response=response, data_type=Transaction)
+        return deserialize(response=response,
+                           data_type=Transaction).set_method(method=self.get_user_transactions,
+                                                             kwargs={"user_id": user_id})
 
     def get_transaction_between_two_users(self, user_id_one: str = None,
                                           user_id_two: str = None,
                                           user_one: User = None,
                                           user_two: User = None,
                                           callback=None,
-                                          count: int = 50,
-                                          before_id=None) -> Union[Transaction, None]:
+                                          limit: int = 50,
+                                          before_id=None) -> Union[Page, None]:
         """
         Get the transactions between two users. Note that user_one must be the owner of the access token.
         Otherwise it raises an unauthorized error.
@@ -167,14 +185,14 @@ class UserApi(object):
         :param user_one:
         :param user_two:
         :param callback:
-        :param count:
+        :param limit:
         :param before_id:
         :return:
         """
         user_id_one = get_user_id(user_one, user_id_one)
         user_id_two = get_user_id(user_two, user_id_two)
 
-        params = {'limit': count}
+        params = {'limit': limit}
         if before_id:
             params['before_id'] = before_id
 
@@ -191,33 +209,7 @@ class UserApi(object):
         if callback:
             return
 
-        return deserialize(response=response, data_type=Transaction)
-
-    @staticmethod
-    def __prepare_offset_limit_params(page_number, max_number_per_page, max_offset, count):
-        """Get the offset for going to that page."""
-        max_page = max_offset//max_number_per_page + 1
-        if page_number == 0 or page_number > max_page:
-            raise InvalidArgumentError(argument_name="'page number'",
-                                       reason=f"Page number must be an int bigger than 1 smaller than {max_page}.")
-
-        offset = (page_number - 1) * max_number_per_page
-
-        return {'offset': offset, 'limit': count}
-
-    @staticmethod
-    def __last_transaction_id(body):
-        pagination = body.get("pagination")
-        if not pagination:
-            return
-
-        next_link = pagination.get("next")
-        pattern = r'before_id=(\d*)'
-        if not next_link:
-            return
-
-        match = re.search(pattern, next_link)
-        if not match.groups():
-            return
-
-        return {"before_id": match.groups()[0]}
+        return deserialize(response=response,
+                           data_type=Transaction).set_method(method=self.get_transaction_between_two_users,
+                                                             kwargs={"user_id_one": user_id_one,
+                                                                             "user_id_two": user_id_two})
